==> micro-website-mall-core-1.0.0-sources.jar: com/ptteng/sca/micro/mall/client/BaseClassifySpuSCAClient.java <==
/**
 * 
 */
package com.ptteng.sca.micro.mall.client;

import java.util.List;
import java.util.Map;

import com.ptteng.micro.mall.model.BaseClassifySpu;
import com.ptteng.micro.mall.service.BaseClassifySpuService;
import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;

public class BaseClassifySpuSCAClient implements BaseClassifySpuService {

    private BaseClassifySpuService baseClassifySpuService;

	public BaseClassifySpuService getBaseClassifySpuService() {
		return baseClassifySpuService;
	}
	
	
	public void setBaseClassifySpuService(BaseClassifySpuService baseClassifySpuService) {
		this.baseClassifySpuService =baseClassifySpuService;
	}
	
	
			   
		@Override
		public Long insert(BaseClassifySpu baseClassifySpu)throws ServiceException, ServiceDaoException{
		
		return baseClassifySpuService.insert(baseClassifySpu);
		          
		
		}	
		  
    	   
		@Override
		public List<BaseClassifySpu> insertList(List<BaseClassifySpu> baseClassifySpuList)throws ServiceException, ServiceDaoException{
		
		return baseClassifySpuService.insertList(baseClassifySpuList);
		          
		
		}	
		  
    	   
		@Override
		public boolean delete(Long id)throws ServiceException, ServiceDaoException{
		
		return baseClassifySpuService.delete(id);
		          
		
		}	
		  
    	   
		@Override
		public boolean update(BaseClassifySpu baseClassifySpu)throws ServiceException, ServiceDaoException{
		
		return baseClassifySpuService.update(baseClassifySpu);
		          
		
		}	
		  
    	   
		@Override
		public boolean updateList(List<BaseClassifySpu> baseClassifySpuList)throws ServiceException, ServiceDaoException{
		
		return baseClassifySpuService.updateList(baseClassifySpuList);
		          
		
		}	
		  
    	   
		@Override
		public BaseClassifySpu getObjectById(Long id)throws ServiceException, ServiceDaoException{
		
		return baseClassifySpuService.getObjectById(id);
		          
		
		}	
		  
    	   
		@Override
		public List<BaseClassifySpu> getObjectsByIds(List<Long> ids)throws ServiceException, ServiceDaoException{
		
		return baseClassifySpuService.getObjectsByIds(ids);
		          
		
		}	
		  
    	
	
	
	
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getBaseClassifySpuIdsBySpuId(Long spuId,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return baseClassifySpuService.getBaseClassifySpuIdsBySpuId(spuId,start,limit);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getBaseClassifySpuIdsByClassifyId(Long classifyId,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return baseClassifySpuService.getBaseClassifySpuIdsByClassifyId(classifyId,start,limit);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getBaseClassifySpuIdsByClassifyIdAndMerchantId(Long classifyId,Long merchantId,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return baseClassifySpuService.getBaseClassifySpuIdsByClassifyIdAndMerchantId(classifyId,merchantId,start,limit);
	
	
	}
	
		
	
	
    			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countBaseClassifySpuIdsBySpuId(Long spuId)throws ServiceException, ServiceDaoException{
		
		return baseClassifySpuService.countBaseClassifySpuIdsBySpuId(spuId);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countBaseClassifySpuIdsByClassifyId(Long classifyId)throws ServiceException, ServiceDaoException{
		
		return baseClassifySpuService.countBaseClassifySpuIdsByClassifyId(classifyId);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countBaseClassifySpuIdsByClassifyIdAndMerchantId(Long classifyId,Long merchantId)throws ServiceException, ServiceDaoException{
		
		return baseClassifySpuService.countBaseClassifySpuIdsByClassifyIdAndMerchantId(classifyId,merchantId);
	
	
	}
	
		
	
		@Override
	public List<Long> getBaseClassifySpuIds(Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return baseClassifySpuService.getBaseClassifySpuIds(start, limit);
	}

	@Override
	public Integer countBaseClassifySpuIds() throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return baseClassifySpuService.countBaseClassifySpuIds();
	}
	
	
	@Override
	public List<Long> getIdsByDynamicCondition(Class clz, Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return baseClassifySpuService.getIdsByDynamicCondition(clz, conditions, start, limit);
	}


	@Override
	public boolean fakeDelete(Class clz, Long id) throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return baseClassifySpuService.fakeDelete(clz, id);
	}
	
	
	
	@Override
	public void deleteList(Class clz, List<Long> ids) throws ServiceException, ServiceDaoException {
		   baseClassifySpuService.deleteList(clz, ids);
		
	}
	
	@Override
	public Object getObjectByDynamicCondition(Class clz,
			Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
	
		return this.baseClassifySpuService.getObjectByDynamicCondition(clz, conditions, start, limit);
	}


 
}

==> micro-website-mall-core-1.1.3-sources.jar: com/ptteng/sca/micro/mall/client/BaseClassifySpuSCAClient.java <==
/**
 * 
 */
package com.ptteng.sca.micro.mall.client;

import java.util.List;
import java.util.Map;

import com.ptteng.micro.mall.model.BaseClassifySpu;
import com.ptteng.micro.mall.service.BaseClassifySpuService;
import com.gemantic.common.exception.ServiceDaoException;
import com.gemantic.common.exception.ServiceException;

public class BaseClassifySpuSCAClient implements BaseClassifySpuService {

    private BaseClassifySpuService baseClassifySpuService;

	public BaseClassifySpuService getBaseClassifySpuService() {
		return baseClassifySpuService;
	}
	
	
	public void setBaseClassifySpuService(BaseClassifySpuService baseClassifySpuService) {
		this.baseClassifySpuService =baseClassifySpuService;
	}
	
	
			   
		@Override
		public Long insert(BaseClassifySpu baseClassifySpu)throws ServiceException, ServiceDaoException{
		
		return baseClassifySpuService.insert(baseClassifySpu);
		          
		
		}	
		  
    	   
		@Override
		public List<BaseClassifySpu> insertList(List<BaseClassifySpu> baseClassifySpuList)throws ServiceException, ServiceDaoException{
		
		return baseClassifySpuService.insertList(baseClassifySpuList);
		          
		
		}	
		  
    	   
		@Override
		public boolean delete(Long id)throws ServiceException, ServiceDaoException{
		
		return baseClassifySpuService.delete(id);
		          
		
		}	
		  
    	   
		@Override
		public boolean update(BaseClassifySpu baseClassifySpu)throws ServiceException, ServiceDaoException{
		
		return baseClassifySpuService.update(baseClassifySpu);
		          
		
		}	
		  
    	   
		@Override
		public boolean updateList(List<BaseClassifySpu> baseClassifySpuList)throws ServiceException, ServiceDaoException{
		
		return baseClassifySpuService.updateList(baseClassifySpuList);
		          
		
		}	
		  
    	   
		@Override
		public BaseClassifySpu getObjectById(Long id)throws ServiceException, ServiceDaoException{
		
		return baseClassifySpuService.getObjectById(id);
		          
		
		}	
		  
    	   
		@Override
		public List<BaseClassifySpu> getObjectsByIds(List<Long> ids)throws ServiceException, ServiceDaoException{
		
		return baseClassifySpuService.getObjectsByIds(ids);
		          
		
		}	
		  
    	
	
	
	
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getBaseClassifySpuIdsBySpuId(Long spuId,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return baseClassifySpuService.getBaseClassifySpuIdsBySpuId(spuId,start,limit);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getBaseClassifySpuIdsByClassifyId(Long classifyId,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return baseClassifySpuService.getBaseClassifySpuIdsByClassifyId(classifyId,start,limit);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public List<Long>  getBaseClassifySpuIdsByClassifyIdAndMerchantId(Long classifyId,Long merchantId,Integer start,Integer limit)throws ServiceException, ServiceDaoException{
		
		return baseClassifySpuService.getBaseClassifySpuIdsByClassifyIdAndMerchantId(classifyId,merchantId,start,limit);
	
	
	}
	
		
	
	
    			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countBaseClassifySpuIdsBySpuId(Long spuId)throws ServiceException, ServiceDaoException{
		
		return baseClassifySpuService.countBaseClassifySpuIdsBySpuId(spuId);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countBaseClassifySpuIdsByClassifyId(Long classifyId)throws ServiceException, ServiceDaoException{
		
		return baseClassifySpuService.countBaseClassifySpuIdsByClassifyId(classifyId);
	
	
	}
	
			
			
		/**
	 * 
	 * @param 
	 * @return 
	 * @throws ServiceException
	 * @throws ServiceDaoException
	 */
	 @Override
	public Integer  countBaseClassifySpuIdsByClassifyIdAndMerchantId(Long classifyId,Long merchantId)throws ServiceException, ServiceDaoException{
		
		return baseClassifySpuService.countBaseClassifySpuIdsByClassifyIdAndMerchantId(classifyId,merchantId);
	
	
	}
	
		
	
		@Override
	public List<Long> getBaseClassifySpuIds(Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return baseClassifySpuService.getBaseClassifySpuIds(start, limit);
	}

	@Override
	public Integer countBaseClassifySpuIds() throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return baseClassifySpuService.countBaseClassifySpuIds();
	}
	
	
	@Override
	public List<Long> getIdsByDynamicCondition(Class clz, Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return baseClassifySpuService.getIdsByDynamicCondition(clz, conditions, start, limit);
	}


	@Override
	public boolean fakeDelete(Class clz, Long id) throws ServiceException, ServiceDaoException {
		// TODO Auto-generated method stub
		return baseClassifySpuService.fakeDelete(clz, id);
	}
	
	
	
	@Override
	public void deleteList(Class clz, List<Long> ids) throws ServiceException, ServiceDaoException {
		   baseClassifySpuService.deleteList(clz, ids);
		
	}
	
	@Override
	public Object getObjectByDynamicCondition(Class clz,
			Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {
	
		return this.baseClassifySpuService.getObjectByDynamicCondition(clz, conditions, start, limit);
	}
	@Override
	public Object getMapListByDynamicCondition(Class clz,
											   Map<String, Object> conditions, Integer start, Integer limit)
			throws ServiceException, ServiceDaoException {

		return this.baseClassifySpuService.getMapListByDynamicCondition(clz, conditions, start, limit);
	}


 
}
